Keen | Responsive Examples
Description: Responsive examples

# Customer Relationship Management

New Order

### Responsive Examples

Reports
Responsive is an extension for DataTables that resolves that problem by optimising the table's layout for different screen sizes through the dynamic insertion and removal of columns from the table. See official documentation here.

### Responsive DataTable

Order ID | Ship Country | Ship City | Ship Name | Ship Address | Company Email | Company Agent | Company Name | Currency | Department | Latitude | Longitude | Ship Date | Payment Date | Time Zone | Total Payment | Status | Type | Actions
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
61715-075 | CN | Tieba | Collins, Dibbert and Hoeger | 746 Pine View Junction | nsailor0@livejournal.com | Nixie Sailor | Gleichner, Ziemann and Gutkowski | CNY | Outdoors | 35.0032213 | 102.913526 | 2/12/2018 | 2016-04-27 23:53:15 | Asia/Chongqing | $246154.65 | 3 | 2 |
63629-4697 | ID | Cihaur | Prosacco-Breitenberg | 01652 Fulton Trail | egiraldez1@seattletimes.com | Emelita Giraldez | Rosenbaum-Reichel | IDR | Toys | -7.1221059 | 106.5701927 | 8/6/2017 | 2017-11-13 14:37:22 | Asia/Jakarta | $795849.41 | 6 | 3 |
68084-123 | AR | Puerto Iguazú | Lebsack-Emard | 2 Pine View Park | uluckin2@state.gov | Ula Luckin | Kulas, Cassin and Batz | ARS | Electronics | -25.6112339 | -54.5515662 | 5/26/2016 | 2018-01-22 12:01:51 | America/Argentina/Cordoba | $830764.07 | 1 | 2 |
67457-428 | ID | Talok | O'Conner, Lebsack and Romaguera | 3050 Buell Terrace | ecure3@trellian.com | Evangeline Cure | Pfannerstill-Treutel | IDR | Automotive | 1.05 | 118.8 | 7/2/2016 | 2017-05-26 08:31:15 | Asia/Jakarta | $777892.92 | 1 | 3 |
31722-529 | AT | Sankt Andrä-Höch | Stehr-Kunde | 3038 Trailsway Junction | tst4@msn.com | Tierney St. Louis | Dicki-Kling | EUR | Health | 46.791555 | 15.379192 | 5/20/2017 | 2016-02-17 10:53:48 | Europe/Vienna | $516467.41 | 2 | 3 |
64117-168 | CN | Rongkou | O'Hara LLC | 023 South Way | greinhard5@instagram.com | Gerhard Reinhard | Gleason, Kub and Marquardt | CNY | Electronics | 37.646108 | 120.477813 | 11/26/2016 | 2018-02-08 07:09:18 | Asia/Shanghai | $410062.16 | 5 | 3 |
43857-0331 | CN | Baiguo | Lebsack Group | 56482 Fairfield Terrace | eshelley6@pcworld.com | Englebert Shelley | Jenkins Inc | CNY | Garden | 26.006775 | 104.512603 | 6/28/2016 | 2017-10-01 05:29:08 | Asia/Chongqing | $210902.65 | 2 | 3 |
64980-196 | HR | Vinica | Gutkowski LLC | 0 Elka Street | hkite7@epa.gov | Hazlett Kite | Streich LLC | HRK | Automotive | 46.3395131 | 16.1537893 | 8/5/2016 | 2017-04-29 22:07:06 | Europe/Zagreb | $1162836.25 | 6 | 1 |
0404-0360 | CO | San Carlos | Bartoletti, Howell and Jacobson | 38099 Ilene Hill | fmorby8@surveymonkey.com | Freida Morby | Haley, Schamberger and Durgan | COP | Garden | 8.797145 | -75.698571 | 3/31/2017 | 2018-02-23 01:18:36 | America/Bogota | $124768.15 | 2 | 1 |
52125-267 | TH | Maha Sarakham | Schroeder-Champlin | 8696 Barby Pass | ohelian9@usatoday.com | Obed Helian | Labadie, Predovic and Hammes | THB | Kids | 16.1991156 | 103.2839975 | 1/26/2017 | 2016-01-17 18:58:57 | Asia/Bangkok | $531999.26 | 1 | 3 |
54092-515 | BR | Canguaretama | Tromp-Murray | 32461 Ridgeway Alley | samya@earthlink.net | Sibyl Amy | Treutel-Ratke | BRL | Health | -6.3810573 | -35.1301043 | 3/8/2017 | 2017-05-24 02:48:57 | America/Fortaleza | $942781.29 | 4 | 2 |
0185-0130 | CN | Jiamachi | Langosh Inc | 23 Walton Pass | nfoldesb@lycos.com | Norri Foldes | Strosin, Nitzsche and Wisozk | CNY | Jewelery | 29.503085 | 108.984759 | 4/2/2017 | 2016-08-05 06:19:54 | Asia/Chongqing | $1143125.96 | 3 | 1 |
21130-678 | CN | Qiaole | Jenkins-Haag | 328 Glendale Hill | morhtmannc@weibo.com | Myrna Orhtmann | Miller-Schiller | CNY | Books | 28.643587 | 115.568583 | 6/7/2016 | 2017-02-02 05:24:00 | Asia/Shanghai | $159355.37 | 3 | 1 |
40076-953 | PT | Burgau | Funk, Lindgren and Bradtke | 52550 Crownhardt Court | skneathd@bizjournals.com | Sioux Kneath | Rice, Cole and Spinka | EUR | Books | 37.0734616 | -8.7751983 | 10/11/2017 | 2016-12-08 07:20:08 | Europe/Lisbon | $381148.49 | 4 | 1 |
36987-3005 | PT | Bacelo | Wolf, Kreiger and Walker | 548 Morrow Terrace | cjacmare@google.pl | Christa Jacmar | Brakus-Hansen | EUR | Electronics | 41.3121037 | -8.1656088 | 8/17/2017 | 2018-05-04 00:10:14 | Europe/Lisbon | $839071.50 | 1 | 2 |
67510-0062 | ZA | Pongola | Kutch and Sons | 02534 Hauk Trail | sgoraccif@thetimes.co.uk | Shandee Goracci | Bergnaum, Thiel and Schuppe | ZAR | Shoes | -33.7363181 | 25.3908518 | 7/24/2016 | 2016-12-12 08:20:58 | Africa/Johannesburg | $924771.59 | 5 | 3 |
36987-2542 | RU | Novokizhinginsk | Beatty LLC | 19427 Sloan Road | jcolvieg@mit.edu | Jerrome Colvie | Kreiger, Glover and Connelly | RUB | Toys | 51.598999 | 109.580475 | 3/4/2016 | 2016-02-06 06:55:10 | Asia/Yakutsk | $708846.15 | 3 | 1 |
11673-479 | BR | Conceição das Alagoas | Gleason Inc | 191 Stone Corner Road | mplenderleithh@globo.com | Michaelina Plenderleith | Legros-Gleichner | BRL | Grocery | -19.9241693 | -48.3811173 | 2/21/2018 | 2016-08-06 05:33:25 | America/Sao_Paulo | $1096683.96 | 1 | 2 |
47781-264 | UA | Yasinya | King, Thiel and Rolfson | 1481 Sauthoff Place | lluthwoodi@constantcontact.com | Lombard Luthwood | Haag LLC | UAH | Books | 48.2595628 | 24.3450737 | 1/21/2016 | 2018-05-20 02:37:25 | Europe/Uzhgorod | $810285.52 | 1 | 2 |
42291-712 | ID | Kembang | Leuschke-Kihn | 9029 Blackbird Point | lchevinj@mapy.cz | Leonora Chevin | Mann LLC | IDR | Movies | -6.4712737 | 110.8171082 | 9/6/2017 | 2016-04-09 20:48:12 | Asia/Jakarta | $868444.96 | 2 | 3 |
64679-154 | MN | Sharga | Kiehn-Bernhard | 102 Holmberg Park | tseakesk@jigsy.com | Tannie Seakes | Blanda Group | MNT | Kids | 46.2686934 | 95.2732977 | 7/31/2016 | 2016-02-13 20:51:30 | Asia/Ulaanbaatar | $32940.02 | 6 | 3 |
49348-055 | CN | Guxi | Fadel Inc | 45 Butterfield Street | ywetherelll@webnode.com | Yardley Wetherell | Gerlach-Schultz | CNY | Shoes | 39.909969 | 116.459299 | 4/3/2017 | 2016-10-22 17:15:35 | Asia/Shanghai | $19446.54 | 2 | 2 |
47593-438 | PT | Viso | Beier-Jones | 97 Larry Center | bpeascodm@devhub.com | Bryn Peascod | Larkin and Sons | EUR | Health | -34.5006776 | -58.8072561 | 5/22/2016 | 2016-09-23 21:49:11 | Europe/Lisbon | $324446.39 | 6 | 1 |
54569-0175 | JP | Minato | Bradtke Group | 077 Hoffman Center | cjeromsonn@ning.com | Chrissie Jeromson | Brakus-McCullough | JPY | Clothing | 35.6726588 | 139.7796498 | 11/26/2017 | 2018-02-03 15:23:53 | Asia/Tokyo | $425962.52 | 2 | 1 |
0093-1016 | ID | Merdeka | Pfannerstill-Jenkins | 3150 Cherokee Center | gclampo@vistaprint.com | Gusti Clamp | Stokes Group | IDR | Grocery | -6.9136675 | 107.6200524 | 4/12/2018 | 2017-10-06 00:23:49 | Asia/Makassar | $158287.28 | 6 | 2 |
0093-5142 | CN | Jianggao | Romaguera-Greenholt | 289 Badeau Alley | ojobbinsp@w3.org | Otis Jobbins | Ruecker, Leffler and Abshire | CNY | Kids | 23.2905 | 113.234549 | 3/6/2018 | 2016-01-01 18:08:34 | Asia/Chongqing | $429312.02 | 4 | 2 |
51523-026 | DE | Erfurt | Stanton Group | 132 Chive Way | lhaycoxq@samsung.com | Lonnie Haycox | Feest Group | EUR | Home | 50.9977219 | 11.0137723 | 4/24/2018 | 2018-04-11 17:08:29 | Europe/Berlin | $219889.84 | 1 | 3 |
49035-522 | AU | Eastern Suburbs Mc | Gleichner-Lebsack | 074 Algoma Drive | hcastellir@nationalgeographic.com | Heddi Castelli | Kessler and Sons | AUD | Games | -33.93274 | 151.188577 | 1/12/2017 | 2016-11-06 16:45:53 | Australia/Sydney | $149602.82 | 5 | 1 |
58411-198 | ET | Kombolcha | Auer Group | 91066 Amoth Court | todowgaines@princeton.edu | Tuck O'Dowgaine | Simonis, Rowe and Davis | ETB | Shoes | 11.0849336 | 39.7291837 | 5/6/2017 | 2017-05-06 01:25:56 | Africa/Addis_Ababa | $1019002.66 | 1 | 1 |
27495-006 | PT | Arrifes | Von LLC | 3 Fairfield Junction | vcoshamt@simplemachines.org | Vernon Cosham | Kreiger-Nicolas | EUR | Movies | 37.760365 | -25.7013016 | 2/8/2017 | 2017-07-22 18:32:31 | Africa/Accra | $179291.15 | 4 | 2 |
55154-8284 | PH | Talisay | McCullough, Okuneva and Heidenreich | 09 Sachtjen Junction | bmaccrackenu@hostgator.com | Bryna MacCracken | Hyatt-Witting | PHP | Games | 14.5618599 | 121.0130439 | 7/22/2017 | 2017-09-03 22:56:12 | Asia/Manila | $26257.28 | 2 | 1 |
62678-207 | LY | Zuwārah | Boehm-Schaden | 82 Thackeray Pass | farnallv@vistaprint.com | Freda Arnall | Dicki, Morar and Stiedemann | LYD | Kids | 32.9234588 | 12.0775411 | 7/22/2016 | 2017-02-12 23:45:54 | Africa/Tripoli | $249720.68 | 3 | 3 |
68428-725 | CN | Zhangcun | Ratke and Sons | 3 Goodland Terrace | pkringew@usatoday.com | Pavel Kringe | Goldner-Lehner | CNY | Jewelery | 43.817071 | 125.323544 | 4/2/2017 | 2016-09-13 14:29:40 | Asia/Shanghai | $593538.58 | 4 | 1 |
0363-0724 | MA | Temara | Hegmann, Gleason and Stehr | 9550 Weeping Birch Crossing | fnazaretx@si.edu | Felix Nazaret | Waters, Quigley and Keeling | MAD | Home | 33.9278354 | -6.9051819 | 6/4/2016 | 2016-06-13 16:43:18 | Africa/Casablanca | $285288.32 | 5 | 3 |
37000-102 | PY | Los Cedrales | Gulgowski, Wyman and Larson | 1 Ridge Oak Way | pallanbyy@discovery.com | Penrod Allanby | Rodriguez Group | PYG | Shoes | -25.6707073 | -54.7412036 | 3/5/2018 | 2016-04-08 12:12:36 | America/Argentina/Cordoba | $827488.58 | 2 | 3 |
55289-002 | PH | Dologon | Prosacco-Bradtke | 9 Vidon Terrace | hpassbyz@wikimedia.org | Hubey Passby | Lemke-Hermiston | PHP | Kids | 7.7601925 | 125.0095225 | 6/29/2017 | 2017-10-04 13:26:41 | Asia/Manila | $293714.61 | 2 | 3 |
15127-874 | TZ | Nanganga | Kozey-Okuneva | 33 Anniversary Parkway | mrotlauf10@naver.com | Magdaia Rotlauf | Hettinger, Medhurst and Heaney | TZS | Beauty | -10.3931514 | 39.1361568 | 2/18/2018 | 2016-08-06 20:08:36 | Africa/Dar_es_Salaam | $290437.32 | 3 | 1 |
49349-123 | ID | Pule | Kuphal Group | 77292 Bonner Plaza | alawrance11@un.org | Alfonse Lawrance | Schuppe-Harber | IDR | Grocery | -8.135667 | 111.5349059 | 4/14/2017 | 2016-04-22 18:11:42 | Asia/Jakarta | $722591.83 | 1 | 3 |
17089-415 | PS | Za‘tarah | Ratke, Schoen and Mitchell | 42806 Ridgeview Terrace | kchettoe12@zdnet.com | Kessiah Chettoe | Mraz LLC | ILS | Automotive | 31.67361 | 35.25662 | 3/4/2017 | 2016-06-10 04:20:27 | Asia/Hebron | $503984.70 | 5 | 2 |
51327-510 | PH | Esperanza | Schneider-Weimann | 4 Linden Court | nfairbanks13@geocities.com | Natka Fairbanks | Mueller-Greenholt | PHP | Health | 14.7342524 | 121.0702642 | 6/21/2017 | 2016-02-21 01:30:35 | Asia/Manila | $89700.35 | 3 | 3 |
Order ID | Ship Country | Ship City | Ship Name | Ship Address | Company Email | Company Agent | Company Name | Currency | Department | Latitude | Longitude | Ship Date | Payment Date | Time Zone | Total Payment | Status | Type | Actions

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!